@@ -391,8 +391,14 @@ class ExecRunner(BaseRunner):
 
         yield self.prepare_status('started')
         most_current_execution_state_time = None
-        while process.poll() is None:
-            time.sleep(RUNNER_RUN_CHECK_INTERVAL)
+        timeout = RUNNER_RUN_CHECK_INTERVAL
+        while process.returncode is None:
+            time.sleep(timeout)
+            try:
+                stdout, stderr = process.communicate(timeout=timeout)
+            except subprocess.TimeoutExpired:
+                # Let's just try again at the next loop
+                pass
             now = time.monotonic()
             if most_current_execution_state_time is not None:
                 next_execution_state_mark = (most_current_execution_state_time +
@@ -402,11 +408,6 @@ class ExecRunner(BaseRunner):
                 most_current_execution_state_time = now
                 yield self.prepare_status('running')
 
-        stdout = process.stdout.read()
-        process.stdout.close()
-        stderr = process.stderr.read()
-        process.stderr.close()
-
         return_code = process.returncode
         yield self.prepare_status('finished', {'returncode': return_code,
                                                'stdout': stdout,
@@ -434,12 +435,13 @@ class ExecTestRunner(ExecRunner):
                                               [])
         for most_current_execution_state in super(ExecTestRunner, self).run():
             returncode = most_current_execution_state.get('returncode')
-            if returncode in skip_codes:
-                most_current_execution_state['result'] = 'skip'
-            elif returncode == 0:
-                most_current_execution_state['result'] = 'pass'
-            else:
-                most_current_execution_state['result'] = 'fail'
+            if returncode is not None:
+                if returncode in skip_codes:
+                    most_current_execution_state['result'] = 'skip'
+                elif returncode == 0:
+                    most_current_execution_state['result'] = 'pass'
+                else:
+                    most_current_execution_state['result'] = 'fail'
             yield most_current_execution_state
 
 
