@@ -1,4 +1,7 @@
 import asyncio
+import sys
+
+from ..settings import settings
 
 
 class StatusServer:
@@ -18,22 +21,28 @@ class StatusServer:
         self._server_task = None
 
     async def create_server(self):
+        limit = settings.as_dict().get('nrunner.status_server_buffer_size')
         if ':' in self._uri:
             host, port = self._uri.split(':')
             port = int(port)
             self._server_task = await asyncio.start_server(
                 self.cb,
                 host=host,
-                port=port)
+                port=port,
+                limit=limit)
         else:
             self._server_task = await asyncio.start_unix_server(
                 self.cb,
-                path=self._uri)
+                path=self._uri,
+                limit=limit)
 
     async def serve_forever(self):
         if self._server_task is None:
             await self.create_server()
-        await self._server_task.serve_forever()
+
+        # TODO: Delete this after deprecation of python 3.6
+        if sys.version_info >= (3, 7):
+            await self._server_task.serve_forever()
 
     def close(self):
         self._server_task.close()
