@@ -29,29 +29,17 @@ import sys
 import tempfile
 import time
 import unittest
-
 from difflib import unified_diff
 
-from . import data_dir
-from . import defaults
-from . import exceptions
-from . import output
-from . import parameters
-from . import sysinfo
-from . import tapparser
-from ..utils import asset
-from ..utils import astring
-from ..utils import data_structures
-from ..utils import genio
+from ..utils import asset, astring, data_structures, genio
 from ..utils import path as utils_path
-from ..utils import process
-from ..utils import stacktrace
+from ..utils import process, stacktrace
+from . import data_dir, exceptions, output, parameters, sysinfo, tapparser
 from .decorators import skip
+from .output import LOG_JOB
 from .settings import settings
 from .test_id import TestID
 from .version import VERSION
-from .output import LOG_JOB
-
 
 #: Environment variable used to store the location of a temporary
 #: directory which is preserved across all tests execution (usually in
@@ -286,7 +274,6 @@ class Test(unittest.TestCase, TestData):
                                            % logdir)
         self.__logdir = utils_path.init_dir(logdir)
         self.__logfile = os.path.join(self.logdir, 'debug.log')
-        self._ssh_logfile = os.path.join(self.logdir, 'remote.log')
 
         self._stdout_file = os.path.join(self.logdir, 'stdout')
         self._stderr_file = os.path.join(self.logdir, 'stderr')
@@ -630,10 +617,6 @@ class Test(unittest.TestCase, TestData):
                                         self._output_file,
                                         raw=True)
 
-        self._register_log_file_handler(logging.getLogger('paramiko'),
-                                        formatter,
-                                        self._ssh_logfile)
-
         if isinstance(sys.stdout, output.LoggingFile):
             sys.stdout.add_logger(log_test_stdout)
         if isinstance(sys.stderr, output.LoggingFile):
@@ -815,7 +798,6 @@ class Test(unittest.TestCase, TestData):
         genio.write_file(whiteboard_file, self.whiteboard)
 
         if self.job is not None:
-            job_standalone = self.job.config.get('standalone', False)
             output_check_record = self.job.config.get('run.output_check_record')
             output_check = self.job.config.get('run.output_check')
 
@@ -832,8 +814,7 @@ class Test(unittest.TestCase, TestData):
                                            "stderr.expected")
 
             # check the output and produce test failures
-            if ((not job_standalone or
-                 output_check_record != 'none') and output_check == 'on'):
+            if output_check_record != 'none' and output_check:
                 output_checked = False
                 try:
                     output_checked = self._check_reference(
@@ -870,9 +851,6 @@ class Test(unittest.TestCase, TestData):
                                                 logger=LOG_JOB)
                         stderr_check_exception = details
 
-        if self.__sysinfo_enabled:
-            self.__sysinfo_logger.end()
-
         # pylint: disable=E0702
         if test_exception is not None:
             raise test_exception
@@ -936,6 +914,8 @@ class Test(unittest.TestCase, TestData):
             for e_line in tb_info:
                 self.log.error(e_line)
         finally:
+            if self.__sysinfo_enabled:
+                self.__sysinfo_logger.end(self.__status)
             self.__phase = 'FINISHED'
             self._tag_end()
             self._report()
@@ -1092,6 +1072,7 @@ class SimpleTest(Test):
         self._command = None
         if self.filename is not None:
             self._command = pipes.quote(self.filename)
+        self._config = settings.as_dict()
 
     @property
     def filename(self):
@@ -1109,6 +1090,13 @@ class SimpleTest(Test):
         self.log.info("Exit status: %s", result.exit_status)
         self.log.info("Duration: %s", result.duration)
 
+    @staticmethod
+    def _cmd_error_to_test_failure(cmd_error):
+        return ("Exited with status: '%u', stdout: %r stderr: %r" %
+                (cmd_error.result.exit_status, cmd_error.result.stdout_text,
+                 cmd_error.result.stderr_text))
+
+
     def _execute_cmd(self):
         """
         Run the executable, and log its detailed execution.
@@ -1117,31 +1105,22 @@ class SimpleTest(Test):
             test_params = dict([(str(key), str(val)) for _, key, val in
                                 self.params.iteritems()])
 
-            result = process.run(self._command, verbose=True,
-                                 env=test_params, encoding=defaults.ENCODING)
+            input_encoding = self._config.get('core.input_encoding')
+            result = process.run(self._command,
+                                 verbose=True,
+                                 env=test_params,
+                                 encoding=input_encoding)
 
             self._log_detailed_cmd_info(result)
         except process.CmdError as details:
             self._log_detailed_cmd_info(details.result)
-            raise exceptions.TestFail(details)
+            test_failure = self._cmd_error_to_test_failure(details)
+            raise exceptions.TestFail(test_failure)
 
-        warn_regex = settings.get_value('simpletests.status',
-                                        'warn_regex',
-                                        key_type='str',
-                                        default=None)
-
-        warn_location = settings.get_value('simpletests.status',
-                                           'warn_location',
-                                           default='all')
-
-        skip_regex = settings.get_value('simpletests.status',
-                                        'skip_regex',
-                                        key_type='str',
-                                        default=None)
-
-        skip_location = settings.get_value('simpletests.status',
-                                           'skip_location',
-                                           default='all')
+        warn_regex = self._config.get('simpletests.status.warn_regex')
+        warn_location = self._config.get('simpletests.status.warn_location')
+        skip_regex = self._config.get('simpletests.status.skip_regex')
+        skip_location = self._config.get('simpletests.status.skip_location')
 
         # Keeping compatibility with 'avocado_warn' libexec
         for regex in [warn_regex, r'^\d\d:\d\d:\d\d WARN \|']:
@@ -1285,9 +1264,12 @@ class TapTest(SimpleTest):
             test_params = {str(key): str(val)
                            for _, key, val in self.params.iteritems()}
 
-            result = process.run(self._command, verbose=True,
+            input_encoding = self._config.get('core.input_encoding')
+            result = process.run(self._command,
+                                 verbose=True,
                                  allow_output_check='stdout',
-                                 env=test_params, encoding=defaults.ENCODING)
+                                 env=test_params,
+                                 encoding=input_encoding)
 
             self._log_detailed_cmd_info(result)
         except process.CmdError as details:
