@@ -1,7 +1,7 @@
 import ast
-import sys
 import os
 import re
+import sys
 import unittest
 
 from avocado.core import safeloader
@@ -9,7 +9,6 @@ from avocado.utils import script
 
 from .. import BASEDIR, setup_avocado_loggers
 
-
 setup_avocado_loggers()
 
 
@@ -44,7 +43,8 @@ class Anyclass(Logger): pass
 '''
 
 RECURSIVE_DISCOVERY_TEST1 = """
-from avocado import Test
+# skip is not used, but stresses the safeloader
+from avocado import skip, Test
 
 class BaseClass(Test):
     def test_basic(self):
@@ -76,7 +76,8 @@ class ThirdChild(Test, SecondChild):
 
 
 RECURSIVE_DISCOVERY_PYTHON_UNITTEST = """
-from unittest import TestCase
+# main is not used, but stresses the safeloader
+from unittest import main, TestCase
 
 class BaseClass(TestCase):
     '''
@@ -318,7 +319,8 @@ class FindClassAndMethods(UnlimitedDiff):
                                  'test_is_not_avocado_test',
                                  'test_is_not_avocado_tests'],
             'PythonModule': ['test_is_avocado_test',
-                             'test_import_of_all_module_level'],
+                             'test_import_of_all_module_level',
+                             'test_import_relative'],
             'ModuleImportedAs': ['_test',
                                  'test_foo',
                                  'test_foo_as_bar',
@@ -366,7 +368,8 @@ class FindClassAndMethods(UnlimitedDiff):
                                  'test_is_not_avocado_test',
                                  'test_is_not_avocado_tests'],
             'PythonModule': ['test_is_avocado_test',
-                             'test_import_of_all_module_level'],
+                             'test_import_of_all_module_level',
+                             'test_import_relative'],
             'ModuleImportedAs': ['test_foo',
                                  'test_foo_as_bar',
                                  'test_foo_as_foo',
@@ -560,6 +563,14 @@ class PythonModule(unittest.TestCase):
             pass
         self.assertIn('unittest', module.mod_imports)
 
+    def test_import_relative(self):
+        """Tests if relative imports are tracked on the module object."""
+        path = os.path.join(BASEDIR, 'selftests', 'functional', 'test_basic.py')
+        module = safeloader.PythonModule(path)
+        for _ in module.iter_classes():
+            pass
+        self.assertIn('TestCaseTmpDir', module.imported_objects)
+
 
 if __name__ == '__main__':
     unittest.main()
