@@ -1,4 +1,3 @@
-import os
 import socket
 import unittest.mock
 
@@ -54,8 +53,6 @@ def get_all_local_addrs():
 
 class FreePort(unittest.TestCase):
 
-    @unittest.skipIf(os.getenv('TRAVIS'),
-                     'TRAVIS Environment is unsuitable for this test')
     @unittest.skipUnless(HAS_NETIFACES,
                          "netifaces library not available")
     def test_is_port_free(self):
